/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const co = require('co')
const apemanport = require('apemanport')
const apemanrequest = require('apemanrequest')
const apemanApp = require('apeman-app')
const assert = require('assert')

describe('create', () => {
  let server, baseUrl
  let request = apemanrequest.create({})
  before(() => co(function * () {
    let app = create([
      (req, res, next) => {
        req._firstHandled = true
        next()
      },
      (req, res, next) => {
        req._secondHandled = true
        next()
      },
      function * gHandle (req, res, next) {
        next()
      },
      (req, res, next) => {
        assert.ok(req._firstHandled)
        assert.ok(req._secondHandled)
        next('someError')
      },
      function * gErrHandle (err, req, res, next) {
        assert.equal(err, 'someError')
        next(err)
      },
      (err, req, res) => {
        assert.equal(err, 'someError')
        res.end('done!')
      }
    ], {})
    assert.ok(app)

    let port = yield apemanport.find()

    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              app
            ]
          }
        }
      }
    })

    baseUrl = `http://localhost:${port}/`
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create', () => co(function * () {
    let res = yield request(baseUrl)
    let { body } = res
    assert.equal(res.statusCode, 200)
    assert.equal(body, 'done!')
  }))
})

/* global describe, before, after, it */
